============
inspire_info
============


.. image:: https://img.shields.io/pypi/v/inspire_info.svg
        :target: https://pypi.python.org/pypi/inspire_info

.. image:: https://img.shields.io/travis/WolfXeHD/inspire_info.svg
        :target: https://travis-ci.com/WolfXeHD/inspire_info

.. image:: https://readthedocs.org/projects/inspire-info/badge/?version=latest
        :target: https://inspire-info.readthedocs.io/en/latest/?version=latest
        :alt: Documentation Status


.. image:: https://pyup.io/repos/github/WolfXeHD/inspire_info/shield.svg
     :target: https://pyup.io/repos/github/WolfXeHD/inspire_info/
     :alt: Updates



Package to retrieve more complex info from inspire than the web-interface allows


* Free software: MIT license
* Documentation: https://inspire-info.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
